raytraverse.scene
==========================================================

Scene
-----------------------

.. autoclass:: raytraverse.scene.Scene
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SunSetterBase
---------------------------

.. autoclass:: raytraverse.scene.SunSetterBase
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SunSetter
---------------------------

.. autoclass:: raytraverse.scene.SunSetter
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SunSetterLoc
---------------------------

.. autoclass:: raytraverse.scene.SunSetterLoc
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SunSetterPositions
---------------------------

.. autoclass:: raytraverse.scene.SunSetterPositions
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SkyInfo
---------------------------

.. autoclass:: raytraverse.scene.SkyInfo
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
